// $Id$
/**
* Copyright (C) 2007 EDIT
* European Distributed Institute of Taxonomy 
* http://www.e-taxonomy.eu
* 
* The contents of this file are subject to the Mozilla Public License Version 1.1
* See LICENSE.TXT at the top of this package for the full license terms.
*/

package eu.etaxonomy.taxeditor.navigation.key.polytomous.handler;

import java.util.List;

import org.eclipse.core.commands.AbstractHandler;
import org.eclipse.core.commands.ExecutionEvent;
import org.eclipse.core.commands.ExecutionException;
import org.eclipse.core.commands.IHandler;
import org.eclipse.core.commands.operations.IUndoContext;
import org.eclipse.core.runtime.IProgressMonitor;
import org.eclipse.core.runtime.IStatus;
import org.eclipse.core.runtime.Status;
import org.eclipse.core.runtime.jobs.Job;

import org.eclipse.swt.widgets.Display;


import eu.etaxonomy.cdm.model.description.PolytomousKey;
import eu.etaxonomy.taxeditor.navigation.NavigationUtil;
import eu.etaxonomy.taxeditor.navigation.key.polytomous.PolytomousKeyViewPart;
import eu.etaxonomy.taxeditor.navigation.key.polytomous.operation.RefreshNodesOperation;
import eu.etaxonomy.taxeditor.operation.AbstractPostOperation;


/**
 * <p>RefreshPolytomousKeyNodesHandler class, which refreshes each key node in the polytomous key navigation view</p>
 *
 * @author c.mathew
 * @created Jan 17 2013
 * @version 1.0
 */
public class RefreshPolytomousKeyNodesHandler extends AbstractHandler implements IHandler {

	@Override
	public Object execute(ExecutionEvent event) throws ExecutionException {
		final PolytomousKeyViewPart view = (PolytomousKeyViewPart) NavigationUtil.getView(PolytomousKeyViewPart.ID, false);
		final List<PolytomousKey> keys = view.getKeys();
		
		final String label = "Refresh Polytomous Key Nodes";
		
		final IUndoContext undoContext = NavigationUtil.getUndoContext();
		if (keys.size() > 0) {
			Job job = new Job("Refreshing Polytomous Key Nodes"){
													
					@Override
					protected IStatus run(IProgressMonitor monitor) {
						monitor.beginTask("Refreshing Polytomous Key Nodes", keys.size());
						
						
							for (final PolytomousKey key : keys) {					
								if(key.getRoot() != null) {

									Display.getDefault().asyncExec(new Runnable(){

										@Override
										public void run() {								    
											AbstractPostOperation operation = new RefreshNodesOperation(label, undoContext, key, view);
											NavigationUtil.executeOperation(operation);
										}

									});
									monitor.worked(1);
								}
							}
							monitor.done();
							return Status.OK_STATUS;
						}

					};

					job.setPriority(Job.SHORT);
					job.schedule();

				}
				return null;
			}
		}

