// $Id$
/**
* Copyright (C) 2015 EDIT
* European Distributed Institute of Taxonomy
* http://www.e-taxonomy.eu
*
* The contents of this file are subject to the Mozilla Public License Version 1.1
* See LICENSE.TXT at the top of this package for the full license terms.
*/
package eu.etaxonomy.taxeditor.navigation.key.polytomous.handler;

import java.util.List;
import java.util.UUID;

import org.eclipse.core.commands.ExecutionEvent;
import org.eclipse.core.commands.operations.AbstractOperation;
import org.eclipse.core.runtime.IStatus;
import org.eclipse.core.runtime.Status;
import org.eclipse.jface.viewers.IStructuredSelection;
import org.eclipse.ui.IEditorInput;
import org.eclipse.ui.IEditorReference;
import org.eclipse.ui.IWorkbenchPage;
import org.eclipse.ui.PartInitException;
import org.eclipse.ui.handlers.HandlerUtil;

import eu.etaxonomy.taxeditor.editor.key.polytomous.PolytomousKeyEditorInput;
import eu.etaxonomy.taxeditor.model.MessagingUtils;
import eu.etaxonomy.taxeditor.navigation.key.polytomous.PolytomousKeyViewLabels;
import eu.etaxonomy.taxeditor.navigation.key.polytomous.operation.RemotingDeletePolytomousKeyOperation;
import eu.etaxonomy.taxeditor.operation.RemotingCdmHandler;
import eu.etaxonomy.taxeditor.util.OperationsUtil;

/**
 * @author cmathew
 * @date 25 Jun 2015
 *
 */
public class RemotingDeletePolytomousKeyHandler extends RemotingCdmHandler {

    List<UUID> keysToDelete;
    /**
     * @param label
     */
    public RemotingDeletePolytomousKeyHandler() {
        super(PolytomousKeyViewLabels.DELETE_POLYTOMOUS_KEY_LABEL);
    }

    /* (non-Javadoc)
     * @see eu.etaxonomy.taxeditor.operation.RemotingCdmHandler#allowOperations(org.eclipse.core.commands.ExecutionEvent)
     */
    @Override
    public IStatus allowOperations(ExecutionEvent event) {
        IStructuredSelection selection = (IStructuredSelection) HandlerUtil.getCurrentSelection(event);

        keysToDelete = OperationsUtil.convertToUuidList(selection.toList());

        if(keysToDelete.isEmpty()){
           return Status.CANCEL_STATUS;
        }

        boolean confirmation = MessagingUtils.confirmDialog("Confirm deletaion", "Do you want to delete the selected key" + (keysToDelete.size() == 1 ? "" : "s") + "?");

        if(!confirmation) {
            return Status.CANCEL_STATUS;
        }
        closeObsoleteEditor(event);
        return Status.OK_STATUS;
    }

    /* (non-Javadoc)
     * @see eu.etaxonomy.taxeditor.operation.RemotingCdmHandler#prepareOperation(org.eclipse.core.commands.ExecutionEvent)
     */
    @Override
    public AbstractOperation prepareOperation(ExecutionEvent event) {
        return new RemotingDeletePolytomousKeyOperation(event.getTrigger(),
                false,
                keysToDelete);
    }

    /* (non-Javadoc)
     * @see eu.etaxonomy.taxeditor.operation.RemotingCdmHandler#onComplete()
     */
    @Override
    public void onComplete() {
        // TODO Auto-generated method stub

    }
    protected boolean closeObsoleteEditor(ExecutionEvent event){
        boolean result = true;
        IWorkbenchPage activePage = HandlerUtil.getActiveWorkbenchWindow(event).getActivePage();

        for (IEditorReference ref : activePage.getEditorReferences()) {
            try {
                IEditorInput input = ref.getEditorInput();
                if (input instanceof PolytomousKeyEditorInput) {
                    UUID uuidForKey = ((PolytomousKeyEditorInput) input).getKey().getUuid();
                    for (UUID keyUuid :keysToDelete) {
                        if( uuidForKey.equals(keyUuid)){
                            result &= activePage.closeEditor(ref.getEditor(false), false);
                        }
                    }

                }
            } catch (PartInitException e) {
                continue;
            }
        }
        return result;
    }

}
