// $Id$
/**
* Copyright (C) 2015 EDIT
* European Distributed Institute of Taxonomy
* http://www.e-taxonomy.eu
*
* The contents of this file are subject to the Mozilla Public License Version 1.1
* See LICENSE.TXT at the top of this package for the full license terms.
*/
package eu.etaxonomy.taxeditor.navigation.navigator.operation;

import java.util.HashSet;
import java.util.Set;
import java.util.UUID;

import org.eclipse.core.runtime.IAdaptable;
import org.eclipse.core.runtime.IProgressMonitor;

import eu.etaxonomy.cdm.api.application.CdmApplicationState;
import eu.etaxonomy.cdm.api.application.CdmChangeEvent.Action;
import eu.etaxonomy.cdm.api.service.ITaxonNodeService;
import eu.etaxonomy.cdm.api.service.UpdateResult;
import eu.etaxonomy.cdm.model.taxon.TaxonNode;
import eu.etaxonomy.taxeditor.navigation.navigator.TreeNodeDropAdapter.MovingType;
import eu.etaxonomy.taxeditor.operation.RemotingCdmUpdateOperation;

/**
 * @author cmathew
 * @date 19 Jun 2015
 *
 */
public class RemotingMoveTaxonOperation extends RemotingCdmUpdateOperation {

    private final static String LABEL = "Move Taxon operation";

    private final Set<UUID> taxonNodesToMoveUuid;
    private final UUID newParentTreeNodeUuid;
    private final MovingType moveToParentNode;

    public RemotingMoveTaxonOperation(Object source,
            boolean async,
            UUID taxonNodeToMoveUuid,
            UUID newParentTreeNodeUuid,
            MovingType moveToParentNode) {
        super(LABEL, Action.Update, source,async);
        taxonNodesToMoveUuid = new HashSet<UUID>();
        taxonNodesToMoveUuid.add(taxonNodeToMoveUuid);
        this.newParentTreeNodeUuid = newParentTreeNodeUuid;
        this.moveToParentNode = moveToParentNode;
    }

    public RemotingMoveTaxonOperation(Object source,
            boolean async,
            TaxonNode taxonNodeToMove,
            TaxonNode newParentTreeNode,
            MovingType moveToParentNode) {
        super(LABEL, Action.Update, source,async);
        taxonNodesToMoveUuid = new HashSet<UUID>();
        taxonNodesToMoveUuid.add(taxonNodeToMove.getUuid());
        this.newParentTreeNodeUuid = newParentTreeNode.getUuid();
        this.moveToParentNode = moveToParentNode;
    }

    public RemotingMoveTaxonOperation(Object source,
            boolean async,
            Set<UUID> taxonNodesToMoveUuid,
            TaxonNode newParentTreeNode,
            MovingType moveToParentNode) {
        super(LABEL, Action.Update, source,async);
        this.taxonNodesToMoveUuid = taxonNodesToMoveUuid;
        this.newParentTreeNodeUuid = newParentTreeNode.getUuid();
        this.moveToParentNode = moveToParentNode;
    }

    /* (non-Javadoc)
     * @see eu.etaxonomy.taxeditor.operation.RemotingCdmUpdateOperation#doUpdateExecute(org.eclipse.core.runtime.IProgressMonitor, org.eclipse.core.runtime.IAdaptable)
     */
    @Override
    protected UpdateResult doUpdateExecute(IProgressMonitor monitor, IAdaptable info) throws Exception {
        switch (this.moveToParentNode) {
            case CHILD:
                return CdmApplicationState.getService(ITaxonNodeService.class).moveTaxonNodes(taxonNodesToMoveUuid,
                        newParentTreeNodeUuid, 0);
            case BEHIND:
                return CdmApplicationState.getService(ITaxonNodeService.class).moveTaxonNodes(taxonNodesToMoveUuid,
                newParentTreeNodeUuid, 2);
             default:
                    UpdateResult result = new UpdateResult();
                    result.setAbort();
                    result.addException(new Exception("The moving type is invalid."));
                    return result;
        }
    }

}
