// $Id$
/**
* Copyright (C) 2015 EDIT
* European Distributed Institute of Taxonomy
* http://www.e-taxonomy.eu
*
* The contents of this file are subject to the Mozilla Public License Version 1.1
* See LICENSE.TXT at the top of this package for the full license terms.
*/
package eu.etaxonomy.taxeditor.navigation.operation;

import java.util.Set;

import org.eclipse.core.commands.ExecutionException;
import org.eclipse.core.commands.operations.IUndoContext;
import org.eclipse.core.runtime.IAdaptable;
import org.eclipse.core.runtime.IProgressMonitor;
import org.eclipse.core.runtime.IStatus;

import eu.etaxonomy.cdm.api.conversation.IConversationEnabled;
import eu.etaxonomy.cdm.api.service.IClassificationService;
import eu.etaxonomy.cdm.api.service.UpdateResult;
import eu.etaxonomy.cdm.model.common.CdmBase;
import eu.etaxonomy.cdm.model.taxon.Classification;
import eu.etaxonomy.taxeditor.model.MessagingUtils;
import eu.etaxonomy.taxeditor.operation.AbstractPersistentPostOperation;
import eu.etaxonomy.taxeditor.operation.IPostOperationEnabled;
import eu.etaxonomy.taxeditor.store.CdmStore;

/**
 * @author a.oppermann
 * @date 28.04.2015
 *
 */
public class CreateNewTaxonHierarchyOperation extends AbstractPersistentPostOperation {

    private final Classification classification;

    private final IClassificationService service;

    /**
     * @param label
     * @param undoContext
     */
    public CreateNewTaxonHierarchyOperation(String label, IUndoContext undoContext, Classification classification,
            IPostOperationEnabled postOperationEnabled,
            IConversationEnabled conversationEnabled) {
        super(label, undoContext, postOperationEnabled, conversationEnabled);

        this.classification = classification;
        this.service = CdmStore.getService(IClassificationService.class);

    }

    @Override
    public IStatus execute(IProgressMonitor monitor, IAdaptable info) throws ExecutionException {

        monitor.worked(20);
        UpdateResult result = service.createHierarchyInClassification(classification, null);
        monitor.worked(60);
        Set<CdmBase> updatedObjects = result.getUpdatedObjects();
        Set<CdmBase> unchangedObjects = result.getUnchangedObjects();
        Classification classification2 = CdmBase.deproxy(result.getCdmEntity(), Classification.class);

        MessagingUtils.informationDialog("Add Hierarchy successful", "New classification is "
      + classification2.getTitleCache() + "\nCreated Genus: " + updatedObjects.size()
      +"\nCreated Subspecies: " + unchangedObjects.size());

        return postExecute(result.getCdmEntity());
    }

    @Override
    public IStatus redo(IProgressMonitor monitor, IAdaptable info) throws ExecutionException {
        return null;
    }

    @Override
    public IStatus undo(IProgressMonitor monitor, IAdaptable info) throws ExecutionException {
        return null;
    }

}
